@@ -3,12 +3,12 @@
 """
 from django.core.management.base import BaseCommand
 
-from django_auditmatic.util import install_triggers
+from django_auditmatic.install.audit import install_audit
 
 
 class Command(BaseCommand):
     """
-    install_triggers command
+    install_audit command
     """
 
     help = "Installs audit table and triggers for the configured models."
@@ -18,4 +18,4 @@ class Command(BaseCommand):
         pass
 
     def handle(self, *args, **options):
-        install_triggers()
+        install_audit()
